@@ -1,6 +1,6 @@
 
 using System;
-using System.Collections;
+using System.Collections.Generic;
 using System.IO;
 using System.Runtime.InteropServices;
 using System.Text.RegularExpressions;
@@ -374,7 +374,7 @@ namespace Tomboy
 		Gtk.TextMark click_mark;
 
 		const string URL_REGEX =
-		        @"((\b((news|http|https|ftp|file|irc)://|mailto:|(www|ftp)\.|\S*@\S*\.)|(^|\s)/\S+/|(^|\s)~/\S+)\S*\b/?)";
+		        @"((\b((news|http|https|ftp|file|irc)://|mailto:|(www|ftp)\.|\S*@\S*\.)|/\S+/|~/\S+)\S*\b/?)";
 
 		static Regex regex;
 		static bool text_event_connected;
@@ -444,9 +444,9 @@ namespace Tomboy
 				url = "file://" +
 				      Path.Combine (Environment.GetEnvironmentVariable ("HOME"),
 				                    url.Substring (2));
-			else if (url.IndexOf ("@") > 1 &&
-			                url.IndexOf (".") > 3 &&
-			                !url.StartsWith ("mailto:"))
+			else if (Regex.IsMatch (url, 
+				@"^(?!(news|mailto|http|https|ftp|file|irc):).+@.{2,}$",
+				RegexOptions.IgnoreCase))
 				url = "mailto:" + url;
 
 			return url;
@@ -460,21 +460,6 @@ namespace Tomboy
 			}
 		}
 
-		void ShowOpeningLocationError (string url, string error)
-		{
-			string message = String.Format ("{0}: {1}", url, error);
-
-			HIGMessageDialog dialog =
-			        new HIGMessageDialog (Window,
-			                              Gtk.DialogFlags.DestroyWithParent,
-			                              Gtk.MessageType.Info,
-			                              Gtk.ButtonsType.Ok,
-			                              Catalog.GetString ("Cannot open location"),
-			                              message);
-			dialog.Run ();
-			dialog.Destroy ();
-		}
-
 		bool OnUrlTagActivated (NoteTag      sender,
 		                        NoteEditor   editor,
 		                        Gtk.TextIter start,
@@ -484,7 +469,7 @@ namespace Tomboy
 			try {
 				OpenUrl (url);
 			} catch (GLib.GException e) {
-				ShowOpeningLocationError (url, e.Message);
+				GuiUtils.ShowOpeningLocationError (Window, url, e.Message);
 			}
 
 			// Kill the middle button paste...
@@ -732,7 +717,25 @@ namespace Tomboy
 
 		void DoHighlight (TrieHit hit, Gtk.TextIter start, Gtk.TextIter end)
 		{
+			// Some of these checks should be replaced with fixes to
+			// TitleTrie.FindMatches, probably.
+			if (hit.Value == null) {
+				Logger.Debug ("DoHighlight: null pointer error for '{0}'." , hit.Key);
+				return;
+			}
+			
+			if (Manager.Find(hit.Key) == null) {
+				Logger.Debug ("DoHighlight: '{0}' links to non-existing note." , hit.Key);
+				return;
+			}
+			
 			Note hit_note = (Note) hit.Value;
+
+			if (String.Compare (hit.Key.ToString(), hit_note.Title.ToString(), true ) != 0) { // == 0 if same string  
+				Logger.Debug ("DoHighlight: '{0}' links wrongly to note '{1}'." , hit.Key, hit_note.Title);
+				return;
+			}
+			
 			if (hit_note == this.Note)
 				return;
 
@@ -783,7 +786,7 @@ namespace Tomboy
 
 		void HighlightInBlock (Gtk.TextIter start, Gtk.TextIter end)
 		{
-			ArrayList hits = Manager.TitleTrie.FindMatches (start.GetSlice (end));
+			IList<TrieHit> hits = Manager.TitleTrie.FindMatches (start.GetSlice (end));
 			foreach (TrieHit hit in hits) {
 				DoHighlight (hit, start, end);
 			}
